"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils = require("../utils");
const nls = require("vscode-nls");
const localize = nls.config({ messageFormat: nls.MessageFormat.file })(__filename);
const extension = require("../../src/extension");
const Profiles_1 = require("../Profiles");
function refreshAllJobs(jobsProvider) {
    return __awaiter(this, void 0, void 0, function* () {
        jobsProvider.mSessionNodes.forEach((jobNode) => {
            if (jobNode.contextValue === extension.JOBS_SESSION_CONTEXT) {
                utils.labelHack(jobNode);
                jobNode.children = [];
                jobNode.dirty = true;
            }
        });
        yield jobsProvider.refresh();
        yield Profiles_1.Profiles.getInstance().refresh();
        const allProf = Profiles_1.Profiles.getInstance().getProfiles();
        jobsProvider.mSessionNodes.forEach((jobNode) => {
            if (jobNode.contextValue === extension.JOBS_SESSION_CONTEXT) {
                for (const profNode of allProf) {
                    if (jobNode.getProfileName() === profNode.name) {
                        jobNode.getProfile().profile = profNode.profile;
                        const SessionProfile = profNode.profile;
                        if (jobNode.getSession().ISession !== SessionProfile) {
                            jobNode.getSession().ISession.user = SessionProfile.user;
                            jobNode.getSession().ISession.password = SessionProfile.password;
                            jobNode.getSession().ISession.base64EncodedAuth = SessionProfile.base64EncodedAuth;
                            jobNode.getSession().ISession.hostname = SessionProfile.hostname;
                            jobNode.getSession().ISession.port = SessionProfile.port;
                            jobNode.getSession().ISession.rejectUnauthorized = SessionProfile.rejectUnauthorized;
                        }
                    }
                }
            }
        });
        yield jobsProvider.refresh();
    });
}
exports.refreshAllJobs = refreshAllJobs;

//# sourceMappingURL=jobNodeActions.js.map
